NotificationBadge class

A widget that displays a notification badge with unread count

Inheritance

Constructors

NotificationBadge({Key? key, required Widget child, required int count, bool showZero = false, Color? badgeColor, Color? textColor, double size = 20.0, Alignment alignment = Alignment.topRight, EdgeInsets padding = const EdgeInsets.all(4.0)})
const

Properties

alignment → Alignment
The badge position
final
badgeColor → Color?
The badge color
final
child → Widget
The child widget to display the badge on
final
count → int
The badge count to display
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsets
The badge padding
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showZero → bool
Whether to show the badge when count is 0
final
size → double
The badge size
final
textColor → Color?
The text color of the badge
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<NotificationBadge>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited