MethodChannelFlutterSystemNotifications class

An implementation of FlutterSystemNotificationsPlatform that uses method channels.

Inheritance

Properties

eventChannel → EventChannel
The event channel for notification events
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

areNotificationsEnabled() → Future<bool>
Check if notifications are enabled
override
cancelAllNotifications() → Future<bool>
Cancel all notifications
override
cancelAllScheduledNotifications() → Future<bool>
Cancel all scheduled notifications
override
cancelNotification(String id) → Future<bool>
Cancel a specific notification
override
cancelScheduledNotification(String id) → Future<bool>
Cancel a scheduled notification
override
clearBadgeCount() → Future<bool>
Clear the badge count
override
clearNotificationHistory() → Future<bool>
Clear notification history/stack
override
getBadgeCount() → Future<int>
Get the current badge count
override
getScheduledNotifications() → Future<List>
Get all scheduled notifications
override
initialize() → Future<bool>
Initialize the notification manager
override
isDuplicateNotification(String duplicateKey, Duration? timeWindow) → Future<bool>
Check if a notification with the same duplicate key exists
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions() → Future<bool>
Request notification permissions
override
scheduleNotification(dynamic scheduledNotification) → Future<bool>
Schedule a notification
override
setBadgeCount(int count) → Future<bool>
Set the badge count
override
showNotification(dynamic request) → Future<bool>
Show a notification
override
toString() → String
A string representation of this object.
inherited
updateScheduledNotification(dynamic notification) → Future<bool>
Update a scheduled notification
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited