FlutterSystemNotificationsPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterSystemNotificationsPlatform
Implementers

Constructors

FlutterSystemNotificationsPlatform()
Constructs a FlutterSystemNotificationsPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

areNotificationsEnabled() → Future<bool>
Check if notifications are enabled
cancelAllNotifications() → Future<bool>
Cancel all notifications
cancelAllScheduledNotifications() → Future<bool>
Cancel all scheduled notifications
cancelNotification(String id) → Future<bool>
Cancel a specific notification
cancelScheduledNotification(String id) → Future<bool>
Cancel a scheduled notification
clearBadgeCount() → Future<bool>
Clear the badge count
clearNotificationHistory() → Future<bool>
Clear notification history/stack
getBadgeCount() → Future<int>
Get the current badge count
getScheduledNotifications() → Future<List>
Get all scheduled notifications
initialize() → Future<bool>
Initialize the notification manager
isDuplicateNotification(String duplicateKey, Duration? timeWindow) → Future<bool>
Check if a notification with the same duplicate key exists
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions() → Future<bool>
Request notification permissions
scheduleNotification(dynamic scheduledNotification) → Future<bool>
Schedule a notification
setBadgeCount(int count) → Future<bool>
Set the badge count
showNotification(dynamic request) → Future<bool>
Show a notification
toString() → String
A string representation of this object.
inherited
updateScheduledNotification(dynamic notification) → Future<bool>
Update a scheduled notification

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterSystemNotificationsPlatform
The default instance of FlutterSystemNotificationsPlatform to use.
getter/setter pair